# satproc

Python library and CLI tools for processing geospatial imagery for ML

## Description

satproc helps you work with large amount of geospatial raster images
(satellite, drone, etc.) and process them for training machine learning, for
object detection or semantic segmentation problems.

## Contributing

Bug reports and pull requests are welcome on GitHub at the [issues
page](https://github.com/dymaxionlabs/satproc). This project is intended to be
a safe, welcoming space for collaboration, and contributors are expected to
adhere to the [Contributor Covenant](http://contributor-covenant.org) code of
conduct.

## License

This project is licensed under Apache 2.0. Refer to [LICENSE.txt](LICENSE.txt).
